Examples
********

.. currentmodule:: ModernGL


.. figure:: Examples/images/01_hello_world.png
	:scale: 50 %
	:alt: Hello World
	:align: center
	:figclass: align-center

	Hello World

.. figure:: Examples/images/03_alpha_blending.png
	:scale: 50 %
	:alt: Alpha Blending
	:align: center
	:figclass: align-center

	Alpha Blending

.. figure:: Examples/images/julia_fractal.png
	:scale: 50 %
	:alt: Julia Fractal
	:align: center
	:figclass: align-center

	Julia Fractal

.. toctree::
	:maxdepth: 4

	01. Hello World <Examples/01_hello_world.rst>
	02. Uniforms and Attributes <Examples/02_uniforms_and_attributes.rst>
	03. Alpha Blending <Examples/03_alpha_blending.rst>
	04. Textures <Examples/04_textures.rst>
	05. Perspective Projection <Examples/05_perspective_projection.rst>
	Julia Fractal <Examples/julia_fractal.rst>
	Particle System <Examples/particle_system.rst>
